#!/bin/bash

# prints network params for FIRST eth card in format: IP MASK GW DNS

DEV=$(ip -br addr show | grep -v lo | head -n 1 | awk '{print $1;}')

if $(systemctl is-enabled NetworkManager 2>&1| grep -q enabled) ; then
    IPM=$(nmcli -m tabular -t -f IP4.ADDRESS device show $DEV | awk '{print $1;}' | tr / ' ' )
    if [ -z "$IPM" ]; then
	find /etc/NetworkManager/system-connections -type f | while read f; do
	    ip=$(grep "address1" "$f" | tr "/" " " | tr "," " " | sed 's/.*=//')
	    dns=$(grep "dns=" "$f" | tr ";" " " | sed 's/.*=//')
	    echo "$ip $dns"
	done
    else
        echo "$IPM $(nmcli -m tabular -t -f IP4.GATEWAY,IP4.DNS device show $DEV | tr / ' ' | tr '\n' ' ')"
    fi
elif netplan get > /dev/null 2>&1; then
    ADDRMASK=$(ip -o -f inet addr show | awk '/scope global/ {print $4}')
    ADDR=$(echo $ADDRMASK | awk -F'/' '{print $1'})
    MASK=$(echo $ADDRMASK | awk -F'/' '{print $2'})
    GW=$(ip r | grep ^def| awk '{print $3}')
    DNS=$(systemd-resolve --status 2>&1 | grep "Current DNS")
    [[ -z $DNS ]] && DNS=$(resolvectl -4 dns -i $DEV | awk -F':' '{print $2}' | awk '{print $1}')
    DNS=${DNS//[[:space:]]}
    echo "$ADDR $MASK $GW $DNS"
else
    F="/etc/network/interfaces"
    ADDR=$(grep address $F| awk '{print $2};')
    MASK=$(grep netmask $F| awk '{print $2};')
    GW=$(grep gateway $F| awk '{print $2};')
    DNS=$(grep nameserver $F| awk '{print $2};')
    echo "$ADDR $MASK $GW $DNS"
fi
