#!/bin/bash

# set network params for FIRST eth card in format: IP MASK GW DNS

if [ "$#" -lt 3 ]; then
    echo "PARAMS COUNT ERROR [$#]: IP MASK GW [DNS]"
    exit -1;
fi

IP=$1
MASK=$2
GW=$3
DNS=$4
[[ -z "$DNS" ]] && DNS="127.0.0.1"
DEV=$(ip -br addr show | grep -v lo | head -n 1 | awk '{print $1;}')
echo "$IP $MASK $GW $DNS $DEV"

if [ $(pgrep NetworkManager) ]; then

    for c in $(nmcli -t --fields UUID con show); do # remove exists
        nmcli con delete $c
    done

    nmcli con add con-name con-name-1 ifname $DEV type ethernet ip4 $IP/$MASK gw4 $GW # create new
    nmcli con mod con-name-1 ipv4.dns "$DNS"

    nmcli connection down id con-name-1 # restart
    nmcli connection up id con-name-1

elif netplan get > /dev/null 2>&1; then
    rm /etc/netplan/*.yaml
cat <<EOT >> /etc/netplan/static_ip.yaml
network:
    version: 2
    renderer: networkd
    ethernets:
        $DEV:
            addresses:
                - $IP/$MASK
            nameservers:
                addresses: [$DNS]
            routes:
                - to: default
                  via: $GW
EOT
    netplan apply
else

    F="/etc/network/interfaces"
    printf "auto lo\niface lo inet loopback\n\n" > $F
    printf "auto $DEV\niface $DEV inet static\n\taddress $IP\n\tnetmask $MASK\n\tgateway $GW\n\tdns-nameservers $DNS\n" >> $F
    ip addr flush $DEV
    systemctl restart networking
fi
