#!/bin/bash

ulimit -c unlimited
shdir=$(dirname $(readlink -nf $(which "$0")))
logdir="/var/tmp/AnnServer_Log"
ERR_TRY_MAX="5"
ERR_TRY="$ERR_TRY_MAX"
ERR_TRY_SECONDS="10"
export PATH="$shdir":$PATH
export LD_LIBRARY_PATH="$shdir/../lib"
RUNLOG() { echo "$(date +'%H:%M:%S.%N') RUNLOG $1" | tee -a "$log_name"; }
mkdir -p "$logdir" > /dev/null 2>&1; chmod 0777 "$logdir" > /dev/null 2>&1 # create log dir

while (( $ERR_TRY > 0 )); do

cd "$shdir" # prepares for this run
pref1="${logdir}/AnnServerLog"; pref2="$((9999999999 - `date +%s`))"
log_name="${pref1}_${pref2}_$(date +%Y%m%d).txt"; touch $log_name; chmod 0666 "$log_name" # log public access
RUNLOG "APP STARTED AT $(date +'%D %T') IN $(pwd) TRY $ERR_TRY"
find /var/spool/asterisk/monitor -type f -mtime +30 -delete # remove old line recordings
find $logdir -type f -mtime +30 -delete # remove old logs
find /var/tmp/AnnServer_WebLog -type f -mtime +30 -delete
[ -d /var/www/voip_tks2/files/distr ] || ln -s /var/tmp/AnnServer_Distr /var/www/voip_tks2/files/distr &>/dev/null # link to distr inside nginx


TIME_START=$(date +%s)
AnnServer LOG_NAME "$log_name" $* 2>&1 | tee -a "$log_name" # run app

eres=${PIPESTATUS[0]} # analize exit result
TIME_STOP=$(date +%s)
RUNLOG "APP EXIT CODE = $eres"
if [ $eres == "200" ]; then
	RUNLOG "NORMAL EXIT"
	break;
elif [ $eres == "205" ]; then
	RUNLOG "UPDATE EXIT"
	break
elif [ $eres == "222" ]; then
	RUNLOG "PLANNED RESTART"
elif [ $eres -lt "200" ]; then
	RUNLOG "QUICK EXIT"
	((TIME_STOP-TIME_START<ERR_TRY_SECONDS)) && ((ERR_TRY--)) || ERR_TRY="$ERR_TRY_MAX"
	sleep 1
else
	RUNLOG "SOME SLEEP BEFORE RERUN ..."
	sleep 1
fi;

done # while
RUNLOG "APP FINISHED AT $(date +'%D %T'), ERR_TRY = $ERR_TRY"
exit $eres
